lists.openwall.net   lists  /  announce  owl-users  owl-dev  john-users  john-dev  passwdqc-users  yescrypt  popa3d-users  /  oss-security  kernel-hardening  musl  sabotage  tlsify  passwords  /  crypt-dev  xvendor  /  Bugtraq  Full-Disclosure  linux-kernel  linux-netdev  linux-ext4  linux-hardening  linux-cve-announce  PHC 
Open Source and information security mailing list archives
 
Hash Suite: Windows password security audit tool. GUI, reports in PDF.
[<prev] [next>] [day] [month] [year] [list]
Date:	Wed, 8 Aug 2012 17:23:49 +0000
From:	David Cullen <David.Cullen@...-americas.com>
To:	Michal Marek <mmarek@...e.cz>
CC:	"linux-kernel@...r.kernel.org" <linux-kernel@...r.kernel.org>
Subject: [RFC PATCHv2] QEMU Fix /usr/bin/xargs: etags: Argument list too long

Patch applies to

    commit 42a579a0f960081cd16fc945036e4780c3ad3202

When running "make ARCH=arm TAGS" in a cross chroot using
qemu-arm-static, the following message is emitted:

    [user@...t:/home/work/linux]: make ARCH=arm TAGS
      GEN     TAGS
    /usr/bin/xargs: etags: Argument list too long

This can be fixed by by passing "-s $((120 * 1024))" to xargs in
scripts/tags.sh when QEMU matches .*qemu-.*-static$.

This limits the xargs command line to 120KiB characters to provide
headroom for people running inside a cross chroot using
qemu-.*-static.

Signed-off-by: David Cullen <david.cullen@...-americas.com>
---
 scripts/tags.sh |   11 +++++++++--
 1 file changed, 9 insertions(+), 2 deletions(-)

diff --git a/scripts/tags.sh b/scripts/tags.sh
index cff8faa..02947c5 100755
--- a/scripts/tags.sh
+++ b/scripts/tags.sh
@@ -5,12 +5,19 @@
 # mode may be any of: tags, TAGS, cscope
 #
 # Uses the following environment variables:
 # ARCH, SUBARCH, SRCARCH, srctree, src, obj

 if [ "$KBUILD_VERBOSE" = "1" ]; then
        set -x
 fi

+# If the user is running in a cross chroot using qemu-.*-static,
+# limit xargs to 120KiB of characters per command line.
+XARGS_MAX_CHARS=
+if [ -n "$QEMU" ] && [[ "$QEMU" =~ .*qemu-.*-static$ ]] ; then
+       XARGS_MAX_CHARS="-s $(( 120 * 1024 ))"
+fi
+
 # This is a duplicate of RCS_FIND_IGNORE without escaped '()'
 ignore="( -name SCCS -o -name BitKeeper -o -name .svn -o \
           -name CVS  -o -name .pc       -o -name .hg  -o \
@@ -121,7 +128,7 @@ dogtags()

 exuberant()
 {
-       all_sources | xargs $1 -a                               \
+       all_sources | xargs $XARGS_MAX_CHARS $1 -a              \
        -I __initdata,__exitdata,__acquires,__releases          \
        -I __read_mostly,____cacheline_aligned                  \
        -I ____cacheline_aligned_in_smp                         \
@@ -5,12 +5,19 @@
 #
 # Uses the following environment variables:
-# ARCH, SUBARCH, SRCARCH, srctree, src, obj
+# ARCH, SUBARCH, SRCARCH, srctree, src, obj, QEMU

 if [ "$KBUILD_VERBOSE" = "1" ]; then
--
1.7.9.5--
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to majordomo@...r.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html
Please read the FAQ at  http://www.tux.org/lkml/

Powered by blists - more mailing lists

Powered by Openwall GNU/*/Linux Powered by OpenVZ